# MahaPala
Detection of fruits disease by using Machine learning

## ಕರ್ನಾಟಕ ರಾಜೋತ್ಸವದ ಶುಭಾಶಯಗಳು

## Release Note

### 2020.11.01.dev
* Initial setup and environments
* Added a templete matching algorithm 
